package tp0;

import java.util.Vector;

/**
 * La classe pour l'index : un vecteur trie sur les mots.
 * @author jroyer
 * 9/12/2010
 */
public class Index extends Vector<Entry> {

	/**
	 * default serial id.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Constructeur par defaut.
	 */
	public Index () {
		super();
	}


	/**
	 * Ajoute une NOUVELLE entree dans l'index.
	 * REQUIRE: !this.isIn(e)
	 * @param e l'entree a ajouter
	 * @return DOIT retourner true
	 */
	// la solution laborieuse
/*	public boolean add(Entry e) {
		if (this.isEmpty()) {
			super.add(e);
		} else if (!this.contains(e)) {
			// ajout a la fin mais uniquement si pas deja dedans
			super.add(e);
			// dernier indice du vecteur
			int i = this.size() - 1;
			// echange les elements si pas dans le bon ordre
			while (i > 0) {
				Entry pred = this.get(i - 1);
				Entry last = this.get(i);
				if (last.compareTo(pred) < 0) {
					this.set(i - 1, last);
					this.set(i, pred);
					i--;
				} else {
					// pour arreter de force
					i = 0;
				}
			}
		}
		return true;
	}*/

	 // autre version
	public boolean add(Entry e) {
		if (this.isEmpty()) {
				super.add(e);
			} else {
				int i = 0;
				while ((i < this.size()) && (e.compareTo(this.get(i))) > 0) {
					i++;
				}
				super.add(i, e);
			}
		return true;
	}

	/**
	 * Determine si le mot est deja reference ou pas.
	 * @param m le mot
	 * @return booleen
	 */
	public boolean isIn(String m) {
		boolean result = false;
		boolean fini = false;
		int i = 0;
		while (!fini && (i < this.size())) {
			if (this.get(i).getMot().equals(m)) {
				fini = true;
				result = true;
			} else {
				i++;
			}
		}
		return result;
	}

	/**
	 * Retourne l'entree correspondant au mot dans l'index.
	 * REQUIRE: this.isIn(mot)
	 * @param m le mot
	 * @return l'entree correspondante
	 */
	public Entry get(String m) {
		boolean fini = false;
		int i = 0;
		while (!fini && (i < this.size())) {
			if (this.get(i).getMot().equals(m)) {
				fini = true;
			} else {
				i++;
			}
		}
		if (fini) {
			return this.get(i);
		} else {
			System.err.println("Index.get: le mot n'y est pas!");
			return null;
		}
	}
	/**
	 * Representation sous forme de chaine.
	 * @return une string
	 */
	public String toString() {
		String result = "";
		for (Entry e : this) {
			result += e + "\n";
		}
		return result;
	}

}
